@@ -240,15 +240,16 @@ def infMap_alg(df_graph):
 
 
 
-def graph_algoritm_selected(df_graph,selection, node_list):
+def graph_algoritm_selected(df_graph,selection,node_list):
 
     len_nodeList = len(node_list)
-    
-    if(selection ==1):
+    print(type(selection))
+    print(selection)
+    if(selection =="1"):
         df_algComu = girvanNewman_alg(node_list,df_graph)
-    elif(selection ==2):
+    elif(selection =="2"):
         df_algComu = leiden_alg(df_graph)
-    elif(selection ==3):
+    elif(selection =="3"):
         df_algComu = infMap_alg(df_graph)
     else:#default
         if(len_nodeList < 1000):
